"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""
# import requests
# import os
#
#
# with open("readme.md", "wb") as f:
#     f.write(requests.get('https://raw.githubusercontent.com/Superior-GitHub/superior6564/main/README.md').content)
#
# path = os.getcwd() + "/readme.md"
# line_need = []
# with open(path) as f:
#     for i in range(5):
#         line = f.readline()[9:]
# version = line
# __author__ = 'Superior_6564'
# __version__ = version
# __email__ = 'vip.klochayil@gmail.com'
